PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/symmetry.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Functions
symmetry.py File Reference

## Namespaces
| pawpyseed.core.symmetry
| Utilities related to symmetry of the crystal structure, namely finding symmetrically identical k-points and the space group operators that map between them.

## Functions
def | pawpyseed.core.symmetry.get_symmops (structure, symprec)
def | pawpyseed.core.symmetry.get_nosym_kpoints (kpts, structure, init_kpts=None, symprec=1e-4, gen_trsym=True, fil_trsym=True)
def | pawpyseed.core.symmetry.get_kpt_mapping (allkpts, kpts, structure, symprec=1e-4, gen_trsym=True)